@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,30 +19,40 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 if ($data['uncheck']) {
 	uncheckTableRows('proxy');
 }
 
 $widget = (new CWidget())
 	->setTitle(_('Proxies'))
-	->setControls((new CForm())
-		->cleanItems()
-		->addItem((new CList())->addItem(new CRedirectButton(_('Create proxy'), 'zabbix.php?action=proxy.edit')))
+	->setControls((new CTag('nav', true,
+		(new CList())
+			->addItem(new CRedirectButton(_('Create proxy'), 'zabbix.php?action=proxy.edit'))
+		))
+			->setAttribute('aria-label', _('Content controls'))
 	)
-	->addItem((new CFilter('web.proxies.filter.state'))
+	->addItem((new CFilter((new CUrl('zabbix.php'))->setArgument('action', 'proxy.list')))
+		->setProfile($data['profileIdx'])
+		->setActiveTab($data['active_tab'])
+		->addFilterTab(_('Filter'), [
+			(new CFormList())->addRow(_('Name'),
+				(new CTextBox('filter_name', $data['filter']['name']))
+					->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH)
+					->setAttribute('autofocus', 'autofocus')
+			),
+			(new CFormList())->addRow(_('Mode'),
+				(new CRadioButtonList('filter_status', (int) $data['filter']['status']))
+					->addValue(_('Any'), -1)
+					->addValue(_('Active'), HOST_STATUS_PROXY_ACTIVE)
+					->addValue(_('Passive'), HOST_STATUS_PROXY_PASSIVE)
+					->setModern(true)
+			)
+		])
 		->addVar('action', 'proxy.list')
-		->addColumn((new CFormList())->addRow(_('Name'),
-			(new CTextBox('filter_name', $data['filter']['name']))
-				->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH)
-				->setAttribute('autofocus', 'autofocus')
-		))
-		->addColumn((new CFormList())->addRow(_('Mode'),
-			(new CRadioButtonList('filter_status', (int) $data['filter']['status']))
-				->addValue(_('Any'), -1)
-				->addValue(_('Active'), HOST_STATUS_PROXY_ACTIVE)
-				->addValue(_('Passive'), HOST_STATUS_PROXY_PASSIVE)
-				->setModern(true)
-		))
 	);
 
 // create form
@@ -55,9 +65,14 @@ $proxyTable = (new CTableInfo())
 			(new CCheckBox('all_hosts'))
 				->onClick("checkAll('".$proxyForm->getName()."', 'all_hosts', 'proxyids');")
 		))->addClass(ZBX_STYLE_CELL_WIDTH),
-		make_sorting_header(_('Name'), 'host', $data['sort'], $data['sortorder']),
+		make_sorting_header(_('Name'), 'host', $data['sort'], $data['sortorder'],
+			(new CUrl('zabbix.php'))
+				->setArgument('action', 'proxy.list')
+				->getUrl()
+		),
 		_('Mode'),
 		_('Encryption'),
+		_('Compression'),
 		_('Last seen (age)'),
 		_('Host count'),
 		_('Item count'),
@@ -91,7 +106,9 @@ foreach ($data['proxies'] as $proxy) {
 			$hosts[] = ', ';
 		}
 
-		$hosts[] = (new CLink($host['name'], 'hosts.php?form=update&hostid='.$host['hostid']))->addClass($style);
+		$hosts[] = $data['allowed_ui_conf_hosts']
+			? (new CLink($host['name'], 'hosts.php?form=update&hostid='.$host['hostid']))->addClass($style)
+			: (new CSpan($host['name']))->addClass($style);
 	}
 
 	$name = new CLink($proxy['host'], 'zabbix.php?action=proxy.edit&proxyid='.$proxy['proxyid']);
@@ -133,7 +150,10 @@ foreach ($data['proxies'] as $proxy) {
 		(new CCol($name))->addClass(ZBX_STYLE_NOWRAP),
 		$proxy['status'] == HOST_STATUS_PROXY_ACTIVE ? _('Active') : _('Passive'),
 		$proxy['status'] == HOST_STATUS_PROXY_ACTIVE ? $out_encryption : $in_encryption,
-		$proxy['lastaccess'] == 0
+		($proxy['auto_compress'] == HOST_COMPRESSION_ON)
+			? (new CSpan(_('On')))->addClass(ZBX_STYLE_STATUS_GREEN)
+			: (new CSpan(_('Off')))->addClass(ZBX_STYLE_STATUS_GREY),
+		($proxy['lastaccess'] == 0)
 			? (new CSpan(_('Never')))->addClass(ZBX_STYLE_RED)
 			: zbx_date2age($proxy['lastaccess']),
 		array_key_exists('host_count', $proxy) ? $proxy['host_count'] : '',
