@@ -27,7 +27,7 @@
 define('CVISIBILITYBOX_JAVASCRIPT_INSERTED', 1);
 
 $output = [
-	'header' => $data['title'],
+	'header' => $data['title']
 ];
 
 $options = $data['options'];
@@ -49,7 +49,9 @@ $operations_popup_form_list = (new CFormList())
 			OPERATION_OBJECT_TRIGGER_PROTOTYPE => _('Trigger prototype'),
 			OPERATION_OBJECT_GRAPH_PROTOTYPE => _('Graph prototype'),
 			OPERATION_OBJECT_HOST_PROTOTYPE => _('Host prototype')
-		]))->setId('operation_object')
+		]))
+			->setId('operationobject')
+			->setReadonly($options['templated'])
 	)
 	->addRow((new CLabel(_('Condition'), 'operator')), [
 		(new CComboBox('operator', $options['operator'], null, [
@@ -60,36 +62,42 @@ $operations_popup_form_list = (new CFormList())
 			CONDITION_OPERATOR_REGEXP => _('matches'),
 			CONDITION_OPERATOR_NOT_REGEXP => _('does not match')
 		]))
-			->addStyle('margin-right:5px;'),
-		(new CTextBox('value', $options['value'], false, DB::getFieldLength('lld_override_operation', 'value')))
+			->setReadonly($options['templated'])
+			->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+		(new CTextBox('value', $options['value'], $options['templated'],
+				DB::getFieldLength('lld_override_operation', 'value')))
 			->setWidth(ZBX_TEXTAREA_MACRO_VALUE_WIDTH)
-			->setAttribute('placeholder', _('pattern')),
+			->setAttribute('placeholder', _('pattern'))
 	])
 	->addRow(
 		(new CVisibilityBox('visible[opstatus]', 'opstatus_status', _('Original')))
 			->setLabel(_('Create enabled'))
-			->setChecked(array_key_exists('opstatus', $options)),
+			->setChecked(array_key_exists('opstatus', $options))
+			->setReadonly($options['templated']),
 		(new CRadioButtonList('opstatus[status]', (int) $field_values['opstatus']['status']))
 			->addValue(_('Yes'), ZBX_PROTOTYPE_STATUS_ENABLED)
 			->addValue(_('No'), ZBX_PROTOTYPE_STATUS_DISABLED)
-			->setModern(true),
+			->setModern(true)
+			->setReadonly($options['templated']),
 		'opstatus_row'
 	)
 	->addRow(
 		(new CVisibilityBox('visible[opdiscover]', 'opdiscover_discover', _('Original')))
 			->setLabel(_('Discover'))
-			->setChecked(array_key_exists('opdiscover', $options)),
+			->setChecked(array_key_exists('opdiscover', $options))
+			->setReadonly($options['templated']),
 		(new CRadioButtonList('opdiscover[discover]', (int) $field_values['opdiscover']['discover']))
 			->addValue(_('Yes'), ZBX_PROTOTYPE_DISCOVER)
 			->addValue(_('No'), ZBX_PROTOTYPE_NO_DISCOVER)
-			->setModern(true),
+			->setModern(true)
+			->setReadonly($options['templated']),
 		'opdiscover_row'
 	);
 
 $update_interval = (new CTable())
 	->setId('update_interval')
 	->addRow([_('Delay'),
-		(new CDiv((new CTextBox('opperiod[delay]', $field_values['opperiod']['delay']))
+		(new CDiv((new CTextBox('opperiod[delay]', $field_values['opperiod']['delay'], $options['templated']))
 			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 		))
 	]);
@@ -109,38 +117,46 @@ foreach ($field_values['opperiod']['delay_flex'] as $i => $delay_flex) {
 	$type_input = (new CRadioButtonList('opperiod[delay_flex]['.$i.'][type]', (int) $delay_flex['type']))
 		->addValue(_('Flexible'), ITEM_DELAY_FLEXIBLE)
 		->addValue(_('Scheduling'), ITEM_DELAY_SCHEDULING)
-		->setModern(true);
+		->setModern(true)
+		->setReadonly($options['templated']);
 
 	if ($delay_flex['type'] == ITEM_DELAY_FLEXIBLE) {
-		$delay_input = (new CTextBox('opperiod[delay_flex]['.$i.'][delay]', $delay_flex['delay']))
+		$delay_input = (new CTextBox('opperiod[delay_flex]['.$i.'][delay]', $delay_flex['delay'],
+				$options['templated']))
 			->setAttribute('placeholder', ZBX_ITEM_FLEXIBLE_DELAY_DEFAULT);
-		$period_input = (new CTextBox('opperiod[delay_flex]['.$i.'][period]', $delay_flex['period']))
+		$period_input = (new CTextBox('opperiod[delay_flex]['.$i.'][period]', $delay_flex['period'],
+				$options['templated']))
 			->setAttribute('placeholder', ZBX_DEFAULT_INTERVAL);
-		$schedule_input = (new CTextBox('opperiod[delay_flex]['.$i.'][schedule]'))
+		$schedule_input = (new CTextBox('opperiod[delay_flex]['.$i.'][schedule]', '', $options['templated']))
 			->setAttribute('placeholder', ZBX_ITEM_SCHEDULING_DEFAULT)
 			->setAttribute('style', 'display: none;');
 	}
 	else {
-		$delay_input = (new CTextBox('opperiod[delay_flex]['.$i.'][delay]'))
+		$delay_input = (new CTextBox('opperiod[delay_flex]['.$i.'][delay]', '', $options['templated']))
 			->setAttribute('placeholder', ZBX_ITEM_FLEXIBLE_DELAY_DEFAULT)
 			->setAttribute('style', 'display: none;');
-		$period_input = (new CTextBox('opperiod[delay_flex]['.$i.'][period]'))
+		$period_input = (new CTextBox('opperiod[delay_flex]['.$i.'][period]', '', $options['templated']))
 			->setAttribute('placeholder', ZBX_DEFAULT_INTERVAL)
 			->setAttribute('style', 'display: none;');
-		$schedule_input = (new CTextBox('opperiod[delay_flex]['.$i.'][schedule]', $delay_flex['schedule']))
+		$schedule_input = (new CTextBox('opperiod[delay_flex]['.$i.'][schedule]', $delay_flex['schedule'],
+				$options['templated']))
 			->setAttribute('placeholder', ZBX_ITEM_SCHEDULING_DEFAULT);
 	}
 
 	$button = (new CButton('opperiod[delay_flex]['.$i.'][remove]', _('Remove')))
 		->addClass(ZBX_STYLE_BTN_LINK)
-		->addClass('element-table-remove');
+		->addClass('element-table-remove')
+		->setEnabled(!$options['templated']);
 
 	$custom_intervals->addRow([$type_input, [$delay_input, $schedule_input], $period_input, $button], 'form_row');
 }
 
 $custom_intervals->addRow([(new CButton('interval_add', _('Add')))
 	->addClass(ZBX_STYLE_BTN_LINK)
-	->addClass('element-table-add')]);
+	->addClass('element-table-add')
+	->setEnabled(!$options['templated'])
+	->removeId()
+]);
 
 $update_interval->addRow(
 	(new CRow([
@@ -153,21 +169,25 @@ $operations_popup_form_list
 	->addRow(
 		(new CVisibilityBox('visible[opperiod]', 'opperiod_div', _('Original')))
 			->setLabel(_('Update interval'))
-			->setChecked(array_key_exists('opperiod', $options)),
+			->setChecked(array_key_exists('opperiod', $options))
+			->setReadonly($options['templated']),
 		(new CDiv($update_interval))->setId('opperiod_div'),
 		'opperiod_row'
 	)
 	->addRow(
 		(new CVisibilityBox('visible[ophistory]', 'ophistory_div', _('Original')))
 			->setLabel(_('History storage period'))
-			->setChecked(array_key_exists('ophistory', $options)),
+			->setChecked(array_key_exists('ophistory', $options))
+			->setReadonly($options['templated']),
 		(new CDiv([
 			(new CRadioButtonList('ophistory[history_mode]', (int) $field_values['ophistory']['history_mode']))
 				->addValue(_('Do not keep history'), ITEM_STORAGE_OFF)
 				->addValue(_('Storage period'), ITEM_STORAGE_CUSTOM)
-				->setModern(true),
+				->setModern(true)
+				->setReadonly($options['templated']),
 			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-			(new CTextBox('ophistory[history]', $field_values['ophistory']['history']))
+			(new CTextBox('ophistory[history]', $field_values['ophistory']['history'], $options['templated'],
+					DB::getFieldLength('lld_override_ophistory', 'history')))
 				->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
 				->setAriaRequired()
 		]))
@@ -178,14 +198,17 @@ $operations_popup_form_list
 	->addRow(
 		(new CVisibilityBox('visible[optrends]', 'optrends_div', _('Original')))
 			->setLabel(_('Trend storage period'))
-			->setChecked(array_key_exists('optrends', $options)),
+			->setChecked(array_key_exists('optrends', $options))
+			->setReadonly($options['templated']),
 		(new CDiv([
 			(new CRadioButtonList('optrends[trends_mode]', (int) $field_values['optrends']['trends_mode']))
 				->addValue(_('Do not keep trends'), ITEM_STORAGE_OFF)
 				->addValue(_('Storage period'), ITEM_STORAGE_CUSTOM)
-				->setModern(true),
+				->setModern(true)
+				->setReadonly($options['templated']),
 			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-			(new CTextBox('optrends[trends]', $field_values['optrends']['trends']))
+			(new CTextBox('optrends[trends]', $field_values['optrends']['trends'], $options['templated'],
+					DB::getFieldLength('lld_override_optrends', 'trends')))
 				->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
 				->setAriaRequired()
 		]))
@@ -196,36 +219,27 @@ $operations_popup_form_list
 	->addRow(
 		(new CVisibilityBox('visible[opseverity]', 'opseverity_div', _('Original')))
 			->setLabel(_('Severity'))
-			->setChecked(array_key_exists('opseverity', $options)),
+			->setChecked(array_key_exists('opseverity', $options))
+			->setReadonly($options['templated']),
 		(new CDiv(
-			new CSeverity([
+			(new CSeverity([
 				'name' => 'opseverity[severity]',
 				'value' => (int) $field_values['opseverity']['severity']
-			])
+			]))->setReadonly($options['templated'])
 		))->setId('opseverity_div'),
 		'opseverity_row'
 	)
-	->addRow(
-		(new CVisibilityBox('visible[optag]', 'optag_div', _('Original')))
-			->setLabel(_('Tags'))
-			->setChecked(array_key_exists('optag', $options)),
-		(new CDiv(
-			renderTagTable($field_values['optag'], false, ['field_name' => 'optag', 'add_post_js' => false])
-				->setHeader([_('Name'), _('Value'), _('Action')])
-				->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
-				->setId('tags-table')
-		))->setId('optag_div'),
-		'optag_row'
-	)
 	->addRow(
 		(new CVisibilityBox('visible[optemplate]', 'optemplate_div', _('Original')))
-			->setLabel(_('Link new templates'))
-			->setChecked(array_key_exists('optemplate', $options)),
+			->setLabel(_('Link templates'))
+			->setChecked(array_key_exists('optemplate', $options))
+			->setReadonly($options['templated']),
 		(new CDiv([
 			(new CMultiSelect([
 				'name' => 'optemplate[]',
 				'object_name' => 'templates',
 				'data' => $field_values['optemplate'],
+				'disabled' => (bool) $options['templated'],
 				'popup' => [
 					'parameters' => [
 						'srctbl' => 'templates',
@@ -239,15 +253,31 @@ $operations_popup_form_list
 		]))->setId('optemplate_div'),
 		'optemplate_row'
 	)
+	->addRow(
+		(new CVisibilityBox('visible[optag]', 'optag_div', _('Original')))
+			->setLabel(_('Tags'))
+			->setChecked(array_key_exists('optag', $options))
+			->setReadonly($options['templated']),
+		(new CDiv(
+			renderTagTable($field_values['optag'], $options['templated'],
+					['field_name' => 'optag', 'add_post_js' => false])
+				->setHeader([_('Name'), _('Value'), _('Action')])
+				->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
+				->setId('tags-table')
+		))->setId('optag_div'),
+		'optag_row'
+	)
 	->addRow(
 		(new CVisibilityBox('visible[opinventory]', 'opinventory_inventory_mode', _('Original')))
 			->setLabel(_('Host inventory'))
-			->setChecked(array_key_exists('opinventory', $options)),
+			->setChecked(array_key_exists('opinventory', $options))
+			->setReadonly($options['templated']),
 		(new CRadioButtonList('opinventory[inventory_mode]', (int) $field_values['opinventory']['inventory_mode']))
 			->addValue(_('Disabled'), HOST_INVENTORY_DISABLED)
 			->addValue(_('Manual'), HOST_INVENTORY_MANUAL)
 			->addValue(_('Automatic'), HOST_INVENTORY_AUTOMATIC)
-			->setModern(true),
+			->setModern(true)
+			->setReadonly($options['templated']),
 		'opinventory_row'
 	);
 
@@ -256,6 +286,7 @@ $output['buttons'] = [
 		'title' => ($options['no'] > 0) ? _('Update') : _('Add'),
 		'class' => '',
 		'keepOpen' => true,
+		'enabled' => !$options['templated'],
 		'isSubmit' => true,
 		'action' => 'return lldoverrides.operations.edit_form.validate(overlay);'
 	]
@@ -263,12 +294,12 @@ $output['buttons'] = [
 
 $operations_popup_form->addItem($operations_popup_form_list);
 
-// HTTP test step editing form.
+// Operations editing form.
 $output['body'] = (new CDiv($operations_popup_form))->toString();
 $output['script_inline'] = 'lldoverrides.operations.onOperationOverlayReadyCb('.$options['no'].');';
-// Get js generated by CVisibilityBox fields and for multiselect fields.
+// Get JS generated by CVisibilityBox fields and for multiselect fields.
 $output['script_inline'] .= getPagePostJs();
-// Unused action rows should be "removed from dom" only after post js will be done.
+// Unused action rows should be "removed from dom" only after post JS will be done.
 $output['script_inline'] .= 'lldoverrides.operations.edit_form.initHideActionRows();';
 
 if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
